calh package
============

Submodules
----------

calh.cli module
---------------

.. automodule:: calh.cli
   :members:
   :undoc-members:
   :show-inheritance:

calh.filter module
------------------

.. automodule:: calh.filter
   :members:
   :undoc-members:
   :show-inheritance:

calh.visualization module
-------------------------

.. automodule:: calh.visualization
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: calh
   :members:
   :undoc-members:
   :show-inheritance:
